@@ -1,6 +1,8 @@
+"""Copyright (C) Nanosurf AG - All Rights Reserved (2021)
+License - MIT"""
 
 import enum
-from nanosurf.lib.devices import i2c 
+import nanosurf.lib.devices.i2c.bus_master as i2c 
 
 class Chip_TCN75(i2c.I2CChip): 
     """ temperature sensor chip"""
